<?php

function preview_sync_configuration_form($form, $form_state) {
  $form['preview_sync_live_alias'] = array(
    '#title' => t('Drush alias for live site'),
    '#field_prefix' => '@',
    '#type' => 'textfield',
    '#required' => TRUE,
    '#default_value' => variable_get('preview_sync_live_alias', 'preview_sync.live'),
    '#description' => t('Drush aliases must be available to Drush worker when called.'),
  );
  $form['preview_sync_preview_alias'] = array(
    '#title' => t('Drush alias for preview site'),
    '#field_prefix' => '@',
    '#type' => 'textfield',
    '#required' => TRUE,
    '#default_value' => variable_get('preview_sync_preview_alias', 'preview_sync.preview'),
    '#description' => t('Drush aliases must be available to Drush worker when called.'),
  );

  // $form['preview_sync_database_dump_file'] = array(
  //   '#title' => t('Database dump filepath'),
  //   '#field_suffix' => '.sql',
  //   '#field_prefix' => 'tmp://',
  //   '#type' => 'textfield',
  //   '#required' => TRUE,
  //   '#default_value' => variable_get('preview_sync_database_dump_file', 'preview_sync-live'),
  //   '#description' => t('The location where the database dump file will be placed.'),
  // );

  $form['preview_sync_preview_base_url'] = array(
    '#title' => t('Preview site base URL'),
    '#type' => 'textfield',
    '#required' => TRUE,
    '#default_value' => variable_get('preview_sync_preview_base_url', ''),
    '#description' => t('The base URL for the preview site. This will be used to link to content in the preview site. Must have trailing slash. E.g. https://www.preview.com/drupal/'),
  );

  return system_settings_form($form);
}


function preview_sync_action_form($form, $form_state) {
  $queue = DrupalQueue::get('preview_sync');
  if ($queue->numberOfItems()) {
    $form['no_dice']['#markup'] = "There is currently pending tasks to run from an existing Preview Sync action. You cannot run another sync until the previous tasks has been complete. Refresh to check status.";
    $form['progress']['#markup'] = views_embed_view('preview_sync_progress');
  }
  else {
    $form['confirm_action']['#markup'] = '';
    if ($cache = cache_get('preview_sync_last_worker_action')) {
      $preview_url = variable_get('preview_sync_preview_base_url', '');
      $form['confirm_action']['#markup'] .= t('<p>Preview site was last syncronised at @time. !link</p>', array(
        '@time' => format_date($cache->data),
        '!link' => empty($preview_url) ? '' : l('View Preview site', $preview_url, array(
          'absolute' => TRUE,
          'attributes' => array('target' => '_blank'),
        )),
      ));
    }
    $form['confirm_action']['#markup'] .= '<p>Below is a summary of content that will be published in the Preview environment when syncronised.</p>';
    $form['confirm_action']['#markup'] .= "<p>Ensure that you've configured " . l('everything correctly', 'admin/config/content/preview-sync') . " first.</p>";
    $form['confirm'] = array(
      '#type' => 'submit',
      '#value' => 'Sync',
    );

    $form['needs_review']['#markup'] = views_embed_view('preview_sync_content_to_publish');
  }
  $form['progress']['#markup'] = views_embed_view('preview_sync_progress');
  return $form;
}

function preview_sync_action_form_submit($form, $form_state) {
  $queue = DrupalQueue::get('preview_sync');
  if ($queue->numberOfItems()) {
    drupal_set_message("Could not initiate preview sync. Previous sync still in progress.");
    return;
  }
  foreach (preview_sync_tasks() as $name => $task) {
    $task['name'] = $name;
    $queue->createItem($task);
  }
}

/**
 * A list of tasks that makes up a whole Preview Sync.
 *
 * @return array
 *   A list of tasks, with each task having:
 *     - title - human readable name of the task, displayed in the
 *     administration UI.
 *     - command - Drush command, with preference for the full version and not
 *     any aliases.
 *     - arguments - arguments to the Drush command.
 */
function preview_sync_tasks() {
  $live = variable_get('preview_sync_live_alias', 'sync.live');
  $preview = variable_get('preview_sync_preview_alias', 'sync.preview');

  $tasks['core_status'] = array(
    'title' => t('Test access to Preview site'),
    'command' => 'core-status',
    'site' => $preview,
  );
  $tasks['rsync'] = array(
    'title' => t('Rsync files'),
    'command' => 'core-rsync',
    'site' => $live,
    'arguments' => array("@$live:%files", "@$preview:%files"),
  );

  $dump_file = drupal_realpath('temporary://') . '/' . variable_get('preview_sync_database_dump_file', 'preview_sync-live') . '.sql';
  $tasks['sql_dump'] = array(
    'title' => t('Dump production database'),
    'command' => 'sql-dump',
    'site' => $live,
    'options' => array(
      'result-file' => $dump_file,
      'no-ordered-dump' => TRUE,
      'structure-tables-list' => 'apachesolr_index_entities,apachesolr_index_entities_node,authmap,cache,cache_apachesolr,cache_block,cache_bootstrap,cache_entity_comment,cache_entity_file,cache_entity_node,cache_entity_taxonomy_term,cache_entity_taxonomy_vocabulary,cache_entity_user,cache_field,cache_file_styles,cache_filter,cache_form,cache_image,cache_libraries,cache_menu,cache_metatag,cache_page,cache_panels,cache_path,cache_rules,cache_styles,cache_token,cache_update,cache_views,cache_views_data,captcha_sessions,ctools_css_cache,ctools_object_cache,flood,forward_log,forward_statistics,history,queue,sessions,watchdog,webform_submissions,webform_submitted_data',
    ),
  );
  $tasks['sql_drop'] = array(
    'title' => t('Drop preview database'),
    'command' => 'sql-drop',
    'site' => $preview,
  );
  $tasks['sql_import'] = array(
    'title' => t('Import dumped database into preview'),
    'command' => 'sqlc < ' . $dump_file,
    'site' => $preview,
  );
  $tasks['env_switch'] = array(
    'title' => t('Environment switch'),
    'command' => 'env-switch',
    'site' => $preview,
    'arguments' => array('preview'),
    'options' => array(
      'force' => TRUE,
      'strict' => FALSE,
    ),
  );
  $tasks['cache_clear'] = array(
    'title' => t('Cache clear'),
    'command' => 'cache-clear',
    'site' => $preview,
    'arguments' => array('all'),
  );
  if (module_exists('workbench_moderation')) {
    $tasks['workbench_moderation_publish'] = array(
      'title' => t('Workbench moderation publish'),
      'command' => 'workbench-moderation-publish',
      'site' => $preview,
    );
  }
  if (module_exists('varnish')) {
    $tasks['varnish'] = array(
      'title' => t('Clear varnish'),
      'command' => 'varnish-purge-all',
      'site' => $preview,
    );
  }
  if (module_exists('apachesolr')) {
    $tasks['solr_drop'] = array(
      'title' => t('Solr drop'),
      'command' => 'solr-delete-index',
      'site' => $preview,
    );
    $tasks['solr_mark'] = array(
      'title' => t('Solr mark'),
      'command' => 'solr-mark-all',
      'site' => $preview,
    );
    $tasks['solr_index'] = array(
      'title' => t('Solr re-index'),
      'command' => 'solr-index',
      'site' => $preview,
    );
  }

  // Allow other modules to jump in if needed.
  drupal_alter('preview_sync_tasks', $tasks, $live, $preview);
  return $tasks;
}
