<?php

/**
 * Implements hook_drush_command()
 */
function preview_sync_drush_command() {
  $items = array();

  $items['workbench-moderation-publish'] = array(
    'aliases' => array('wmp'),
    'description' => dt('Publishes all Drupal content in the "review" state. This should only ever be run on the preview server. The command assumes you are using the workbench_moderation module for workflow.'),
    'options' => array(
      'offset' => dt('What index should the content be published starting at. Defaults to 0.'),
      'limit' => dt('How many items of content should be published (after the offset). Defaults to all content.'),
    ),
    'bootstrap' => DRUSH_BOOTSTRAP_DRUPAL_FULL,
    'drupal dependencies' => array('preview_sync', 'workbench_moderation'),
    'examples' => array(
      'drush workbench-moderation-publish @preview' => dt('Publishes all Drupal content in the review state.'),
      'drush workbench-moderation-publish @preview --offset=10 --limit=10' => dt('Publishes Drupal content in the review state with an offset of the first 10 items, processing the next 10 items.'),
    ),
  );

  return $items;
}

/**
 * Implements hook_drush_help().
 */
function preview_sync_drush_help($section) {
  switch ($section) {
    case 'drush:workbench-moderation-publish' :
      return dt('Publishes all Drupal content in the "review" state. This should only ever be run on the preview server. The command assumes you are using the workbench_moderation module for workflow.');
  }
}

/**
 * Basic validation for the arguments to the Drush command.
 */
function drush_preview_sync_workbench_moderation_publish_validate() {
  $offset = trim(drush_get_option('offset'));
  if ($offset) {
    if (!is_numeric($offset) || $offset < 0) {
      return drush_set_error('INVALID_OFFSET_FORMAT', dt('Offset argument must be a positive integer (e.g. 10)'));
    }
  }

  $limit = trim(drush_get_option('limit'));
  if ($limit) {
    if (!is_numeric($limit) || $limit < 1) {
      return drush_set_error('INVALID_LIMIT_FORMAT', dt('Limit argument must be a positive integer (e.g. 10)'));
    }
  }
}

/**
 * Publishes content in the review state.
 */
function drush_preview_sync_workbench_moderation_publish() {
  $offset = trim(drush_get_option('offset'));
  if (empty($offset)) {
    $offset = 0;
  }
  $limit = trim(drush_get_option('limit'));
  if (empty($limit)) {
    $limit = 10000;
  }

  $nodes = preview_sync_get_review_content($offset, $limit);
  foreach ($nodes as $node) {
    $revision = node_load($node['nid'], $node['vid']);
    $revision->status = 1;
    $revision->workbench_moderation_state_new = workbench_moderation_state_published();
    node_save($revision);
  }
}
